# MalKit

[![PyPI](https://img.shields.io/pypi/v/malkit)](https://pypi.org/project/malkit/)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/malkit)](https://pypi.org/project/malkit/)
[![PyPI - Downloads](https://img.shields.io/pypi/dm/malkit)](https://pypi.org/project/malkit/)
[![PyPI - License](https://img.shields.io/pypi/l/malkit)](https://pypi.org/project/malkit/)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![Imports: isort](https://img.shields.io/badge/%20imports-isort-%231674b1?style=flat&labelColor=ef8336)](https://pycqa.github.io/isort/)

MalKit is a malware analysis toolkit for machine learning.

## Installation

Install from PyPI:

```shell
$ pip install malkit
```

If you want to use `malkit.torch`, you should install PyTorch manually since it is not declared as a dependency.
